# CXRsegmentation
Проект по сегментации легких сделанный в рамках проектной смены Сириуса 'Большие вызовы'. 
Программа модуля разработана Центром ИИ Университета Иннополис. 
### Основная идея
Распознать легкие и отсегментировать их.
### Стек технологий:
Для этого предполагается использование следующий стек технологий:
* > Linux (Ubuntu)
* > Python, pip, numpy, PyTorch, Pathlib и т.д.
* > OpenCV 
* > Machine learning or Deep learning 
* > Jupyter lab / Jupyter Notebook
* > To be added
